@@ -105,7 +105,7 @@ types: dict[str, str] = {
     "AWS::AutoScaling::ScheduledAction": "ab00e084f1d921e6",
     "AWS::AutoScaling::WarmPool": "93498a4faffea6ae",
     "AWS::AutoScalingPlans::ScalingPlan": "0a636faf3e94411d",
-    "AWS::Backup::BackupPlan": "72bcc201f012e665",
+    "AWS::Backup::BackupPlan": "320b6510a85d684e",
     "AWS::Backup::BackupSelection": "26040166156c899a",
     "AWS::Backup::BackupVault": "695e80a4aaec9275",
     "AWS::Backup::Framework": "df47da6f2d6712da",
@@ -165,7 +165,7 @@ types: dict[str, str] = {
     "AWS::CloudFront::DistributionTenant": "0645b8023b061e15",
     "AWS::CloudFront::Function": "f3bfd8485e232a78",
     "AWS::CloudFront::KeyGroup": "7a9f609d809f1f8e",
-    "AWS::CloudFront::KeyValueStore": "674d07fa20c06be2",
+    "AWS::CloudFront::KeyValueStore": "59c36f41cb955ac8",
     "AWS::CloudFront::MonitoringSubscription": "f9dae15a96e422a7",
     "AWS::CloudFront::OriginAccessControl": "17f386694e5709fe",
     "AWS::CloudFront::OriginRequestPolicy": "97711158d1bc4353",
@@ -230,7 +230,7 @@ types: dict[str, str] = {
     "AWS::Connect::DataTableAttribute": "08713b122feb23e4",
     "AWS::Connect::DataTableRecord": "db6c4d160c0da36f",
     "AWS::Connect::EmailAddress": "807b7160b3385afb",
-    "AWS::Connect::EvaluationForm": "f723bee2405abd32",
+    "AWS::Connect::EvaluationForm": "d4ec84ca94cd03eb",
     "AWS::Connect::HoursOfOperation": "0ad5f5246de080b7",
     "AWS::Connect::Instance": "818f2e8da01f29d9",
     "AWS::Connect::InstanceStorageConfig": "036e51d554e029ec",
@@ -303,7 +303,8 @@ types: dict[str, str] = {
     "AWS::DocDB::DBInstance": "253562f270b587ac",
     "AWS::DocDB::DBSubnetGroup": "ccb97a9452b2284d",
     "AWS::DocDB::EventSubscription": "d22815028d03f301",
-    "AWS::DynamoDB::GlobalTable": "1789ed6c17b2b960",
+    "AWS::DocDB::GlobalCluster": "8a43a2ee7a595e9a",
+    "AWS::DynamoDB::GlobalTable": "bfb73ef91cc656d2",
     "AWS::DynamoDB::Table": "8e1902cddc19c9ad",
     "AWS::EC2::CapacityReservation": "d8685a879c65fa62",
     "AWS::EC2::CapacityReservationFleet": "3cec76abc326e6e7",
@@ -323,7 +324,7 @@ types: dict[str, str] = {
     "AWS::EC2::Host": "ba21ffd03e701456",
     "AWS::EC2::IPAM": "6fc9a0643e75121d",
     "AWS::EC2::IPAMAllocation": "c4cba824ca02ce4f",
-    "AWS::EC2::IPAMPool": "99dd938378f53c74",
+    "AWS::EC2::IPAMPool": "0509442cdc1e18b1",
     "AWS::EC2::IPAMPoolCidr": "873e7cc6e6afef96",
     "AWS::EC2::IPAMResourceDiscovery": "694c0afb626c30d8",
     "AWS::EC2::IPAMResourceDiscoveryAssociation": "fde93486402ddbe5",
@@ -354,6 +355,11 @@ types: dict[str, str] = {
     "AWS::EC2::PlacementGroup": "8dca9ce7eb8b50ac",
     "AWS::EC2::PrefixList": "c53292c8686d14de",
     "AWS::EC2::Route": "0ff811157612151a",
+    "AWS::EC2::RouteServer": "f53338d8b3c6499a",
+    "AWS::EC2::RouteServerAssociation": "22bb952c9a61f2a9",
+    "AWS::EC2::RouteServerEndpoint": "40a2b7461aa985fa",
+    "AWS::EC2::RouteServerPeer": "0b52f45b8ea8cbac",
+    "AWS::EC2::RouteServerPropagation": "0dd3a42d71c85b11",
     "AWS::EC2::RouteTable": "67bdbfcad069c66a",
     "AWS::EC2::SecurityGroup": "5390282384be7866",
     "AWS::EC2::SecurityGroupEgress": "840df778de9b4be2",
@@ -412,10 +418,10 @@ types: dict[str, str] = {
     "AWS::ECR::Repository": "d569f41026af3be8",
     "AWS::ECR::RepositoryCreationTemplate": "38e9548ebe8ec1f5",
     "AWS::ECR::SigningConfiguration": "c502bcdb31b67cc1",
-    "AWS::ECS::CapacityProvider": "683155ff5bdccc42",
+    "AWS::ECS::CapacityProvider": "7dac44a9d26fc538",
     "AWS::ECS::Cluster": "3990111074eac8be",
     "AWS::ECS::ClusterCapacityProviderAssociations": "4b512d1fe30ffdd3",
-    "AWS::ECS::ExpressGatewayService": "5d3c22b7a1c19b87",
+    "AWS::ECS::ExpressGatewayService": "a04769bd1a468834",
     "AWS::ECS::PrimaryTaskSet": "d8ea9e906cb85b80",
     "AWS::ECS::Service": "585001d48158728c",
     "AWS::ECS::TaskDefinition": "ac3c5ff140cb5d7d",
@@ -429,7 +435,7 @@ types: dict[str, str] = {
     "AWS::EKS::Cluster": "f17916cc287d09df",
     "AWS::EKS::FargateProfile": "71e821ce6e609193",
     "AWS::EKS::IdentityProviderConfig": "77b807192827540b",
-    "AWS::EKS::Nodegroup": "287f4d78035a9e03",
+    "AWS::EKS::Nodegroup": "4b7b3ba6fffc3e8a",
     "AWS::EKS::PodIdentityAssociation": "d4249aaeb9409683",
     "AWS::EMR::Cluster": "ac0466c8197ef416",
     "AWS::EMR::InstanceFleetConfig": "7c6308bb9ea61ce8",
@@ -571,7 +577,7 @@ types: dict[str, str] = {
     "AWS::KMS::Alias": "28f10f922a4d194f",
     "AWS::KMS::Key": "c70e396ee12ddb65",
     "AWS::KMS::ReplicaKey": "903f43e74c8d8853",
-    "AWS::KafkaConnect::Connector": "08b81c973eb812dd",
+    "AWS::KafkaConnect::Connector": "9ca5dec677704b80",
     "AWS::KafkaConnect::CustomPlugin": "f04fc57818e8ddb4",
     "AWS::KafkaConnect::WorkerConfiguration": "8a9b885926e8a00c",
     "AWS::Kinesis::ResourcePolicy": "39996915810e234a",
@@ -607,7 +613,7 @@ types: dict[str, str] = {
     "AWS::Logs::DeliverySource": "67b64320b397d6cd",
     "AWS::Logs::Destination": "ff1e6b020f2cf8e7",
     "AWS::Logs::LogAnomalyDetector": "e2ee984f7c775ef5",
-    "AWS::Logs::LogGroup": "7144d581f2e97160",
+    "AWS::Logs::LogGroup": "364a0898ae2cfeb8",
     "AWS::Logs::LogStream": "bb97d1fb38ff99db",
     "AWS::Logs::MetricFilter": "9a1d875b35cd0f81",
     "AWS::Logs::QueryDefinition": "7b82b12db189c1d9",
@@ -695,10 +701,10 @@ types: dict[str, str] = {
     "AWS::PaymentCryptography::Key": "af26a71fe21eb480",
     "AWS::Pipes::Pipe": "052457cd8332df71",
     "AWS::QuickSight::Analysis": "9ed141915b114fbd",
-    "AWS::QuickSight::CustomPermissions": "ac2895cdbe3ee0f3",
+    "AWS::QuickSight::CustomPermissions": "da6da182c0c23fb4",
     "AWS::QuickSight::Dashboard": "b1b7368590994f86",
     "AWS::QuickSight::DataSet": "0e9e94a2fd9e8f95",
-    "AWS::QuickSight::DataSource": "2c06940063cc0519",
+    "AWS::QuickSight::DataSource": "407708b753626383",
     "AWS::QuickSight::Folder": "4a9e4af92dbcc718",
     "AWS::QuickSight::RefreshSchedule": "0e848e5d85a17427",
     "AWS::QuickSight::Template": "9f99a52291094b16",
@@ -708,7 +714,7 @@ types: dict[str, str] = {
     "AWS::RAM::ResourceShare": "b4b5ff31bc5f95b0",
     "AWS::RDS::DBCluster": "9c7540d3d4699497",
     "AWS::RDS::DBClusterParameterGroup": "4e3460620664c07f",
-    "AWS::RDS::DBInstance": "b7cc196bc1fe0b0d",
+    "AWS::RDS::DBInstance": "25726c9e8467f4c5",
     "AWS::RDS::DBParameterGroup": "d29cf38b861f6048",
     "AWS::RDS::DBProxy": "6a3bd3de0c3a9c96",
     "AWS::RDS::DBProxyEndpoint": "db0fcba23f51c12d",
@@ -787,7 +793,7 @@ types: dict[str, str] = {
     "AWS::S3Tables::TableBucketPolicy": "b3ab0f647d7aed60",
     "AWS::S3Tables::TablePolicy": "0ed301e1967bd6a0",
     "AWS::SDB::Domain": "48c38397df169b43",
-    "AWS::SES::ConfigurationSet": "77b6745a5f444407",
+    "AWS::SES::ConfigurationSet": "97470ae3c0d408ae",
     "AWS::SES::ConfigurationSetEventDestination": "f4e74b1d7e859c34",
     "AWS::SES::ContactList": "c5a40d0f3d530e19",
     "AWS::SES::DedicatedIpPool": "1485a5989d771f62",
@@ -857,7 +863,7 @@ types: dict[str, str] = {
     "AWS::SageMaker::Project": "c10c82bc5a09a5dc",
     "AWS::SageMaker::Space": "a50f6b85f86355b5",
     "AWS::SageMaker::StudioLifecycleConfig": "5b453bb7816eb95b",
-    "AWS::SageMaker::UserProfile": "d2a4b7455b2cbd74",
+    "AWS::SageMaker::UserProfile": "6300c02533605472",
     "AWS::SageMaker::Workteam": "d617e40122a8fe93",
     "AWS::Scheduler::Schedule": "e8b60514af25a837",
     "AWS::Scheduler::ScheduleGroup": "ef710d09dbb243bf",
@@ -965,7 +971,7 @@ types: dict[str, str] = {
     "AWS::WAFv2::WebACL": "892990086386d387",
     "AWS::WAFv2::WebACLAssociation": "d0181fa0b0d2faac",
     "AWS::WorkSpaces::Workspace": "97435699d74bcbe8",
-    "AWS::WorkspacesInstances::Volume": "783536e2ad8748b1",
+    "AWS::WorkspacesInstances::Volume": "dc5bec0e6e8edd13",
     "AWS::WorkspacesInstances::VolumeAssociation": "de659b329d22edbd",
     "AWS::WorkspacesInstances::WorkspaceInstance": "d9e9f739e378d7cd",
     "AWS::XRay::Group": "81cf1b3bfd81fc73",
