@@ -124,7 +124,7 @@ types: dict[str, str] = {
     "AWS::AutoScaling::ScheduledAction": "ab00e084f1d921e6",
     "AWS::AutoScaling::WarmPool": "93498a4faffea6ae",
     "AWS::AutoScalingPlans::ScalingPlan": "81df3d07362fff07",
-    "AWS::Backup::BackupPlan": "72bcc201f012e665",
+    "AWS::Backup::BackupPlan": "320b6510a85d684e",
     "AWS::Backup::BackupSelection": "26040166156c899a",
     "AWS::Backup::BackupVault": "695e80a4aaec9275",
     "AWS::Backup::Framework": "df47da6f2d6712da",
@@ -151,8 +151,8 @@ types: dict[str, str] = {
     "AWS::Bedrock::KnowledgeBase": "42afb318cede00fc",
     "AWS::Bedrock::Prompt": "63cb5b7f989bfc36",
     "AWS::Bedrock::PromptVersion": "41e3e79078ba156a",
-    "AWS::BedrockAgentCore::Gateway": "247c1db4e4082ec0",
-    "AWS::BedrockAgentCore::GatewayTarget": "2214118622bce5a2",
+    "AWS::BedrockAgentCore::Gateway": "a629441d622699ce",
+    "AWS::BedrockAgentCore::GatewayTarget": "f190da008ea2a70a",
     "AWS::BedrockAgentCore::WorkloadIdentity": "78d4c036021cc12e",
     "AWS::Budgets::Budget": "ebac0f729cbbf76a",
     "AWS::Budgets::BudgetsAction": "e06dd2791075c9d6",
@@ -276,7 +276,7 @@ types: dict[str, str] = {
     "AWS::Connect::DataTableAttribute": "08713b122feb23e4",
     "AWS::Connect::DataTableRecord": "db6c4d160c0da36f",
     "AWS::Connect::EmailAddress": "807b7160b3385afb",
-    "AWS::Connect::EvaluationForm": "f723bee2405abd32",
+    "AWS::Connect::EvaluationForm": "d4ec84ca94cd03eb",
     "AWS::Connect::HoursOfOperation": "0ad5f5246de080b7",
     "AWS::Connect::Instance": "818f2e8da01f29d9",
     "AWS::Connect::InstanceStorageConfig": "036e51d554e029ec",
@@ -342,13 +342,13 @@ types: dict[str, str] = {
     "AWS::DataSync::LocationS3": "0190e1a20831d5e0",
     "AWS::DataSync::LocationSMB": "84f56a8c81ace8fd",
     "AWS::DataSync::Task": "d896b335ffc11f10",
-    "AWS::DataZone::Connection": "4c5bd872b555a360",
-    "AWS::DataZone::DataSource": "45679439037c4108",
+    "AWS::DataZone::Connection": "36206200921236e5",
+    "AWS::DataZone::DataSource": "5522a6a5cd1e1a3e",
     "AWS::DataZone::Domain": "a73fade42476d81b",
     "AWS::DataZone::DomainUnit": "711f0c6aabf717bd",
     "AWS::DataZone::Environment": "90d9cbf3a3ed746b",
     "AWS::DataZone::EnvironmentActions": "74f98b0cb8b35451",
-    "AWS::DataZone::EnvironmentBlueprintConfiguration": "3aeda3b79f4458c1",
+    "AWS::DataZone::EnvironmentBlueprintConfiguration": "2eaef7d5eed54c20",
     "AWS::DataZone::EnvironmentProfile": "e0cb32e5d86cbc08",
     "AWS::DataZone::FormType": "c4cdf1e5e0a284ed",
     "AWS::DataZone::GroupProfile": "74ae2ae09d16d68e",
@@ -356,8 +356,8 @@ types: dict[str, str] = {
     "AWS::DataZone::PolicyGrant": "4a122be9c506c908",
     "AWS::DataZone::Project": "2f7d1fc808f3eed8",
     "AWS::DataZone::ProjectMembership": "9afaeb6b2c0a7ad8",
-    "AWS::DataZone::ProjectProfile": "fb23ccf55c4c1ec7",
-    "AWS::DataZone::SubscriptionTarget": "b9b0c7c5b0d7c587",
+    "AWS::DataZone::ProjectProfile": "069e12fef6b972f5",
+    "AWS::DataZone::SubscriptionTarget": "ed731ffbd196f802",
     "AWS::DataZone::UserProfile": "db3a5863b7d055bd",
     "AWS::Detective::Graph": "dbed0b7e7b29e1e6",
     "AWS::Detective::MemberInvitation": "86355f574dcf77f5",
@@ -372,8 +372,9 @@ types: dict[str, str] = {
     "AWS::DocDB::DBInstance": "253562f270b587ac",
     "AWS::DocDB::DBSubnetGroup": "ccb97a9452b2284d",
     "AWS::DocDB::EventSubscription": "d22815028d03f301",
+    "AWS::DocDB::GlobalCluster": "8a43a2ee7a595e9a",
     "AWS::DocDBElastic::Cluster": "5686e00f54e9aae6",
-    "AWS::DynamoDB::GlobalTable": "1789ed6c17b2b960",
+    "AWS::DynamoDB::GlobalTable": "bfb73ef91cc656d2",
     "AWS::DynamoDB::Table": "8e1902cddc19c9ad",
     "AWS::EC2::CapacityManagerDataExport": "eadbbd5d7fd8fd3c",
     "AWS::EC2::CapacityReservation": "d8685a879c65fa62",
@@ -385,7 +386,7 @@ types: dict[str, str] = {
     "AWS::EC2::ClientVpnTargetNetworkAssociation": "d69233d655faf0f6",
     "AWS::EC2::CustomerGateway": "4003177e29b1dfc5",
     "AWS::EC2::DHCPOptions": "7794e3a54eaacb7a",
-    "AWS::EC2::EC2Fleet": "2667c807051620b3",
+    "AWS::EC2::EC2Fleet": "46456be2fbbfb010",
     "AWS::EC2::EIP": "cc42df82cdc81e9c",
     "AWS::EC2::EIPAssociation": "a267820d6250f189",
     "AWS::EC2::EgressOnlyInternetGateway": "922c59e19b698eac",
@@ -395,7 +396,7 @@ types: dict[str, str] = {
     "AWS::EC2::Host": "ba21ffd03e701456",
     "AWS::EC2::IPAM": "6fc9a0643e75121d",
     "AWS::EC2::IPAMAllocation": "c4cba824ca02ce4f",
-    "AWS::EC2::IPAMPool": "99dd938378f53c74",
+    "AWS::EC2::IPAMPool": "0509442cdc1e18b1",
     "AWS::EC2::IPAMPoolCidr": "873e7cc6e6afef96",
     "AWS::EC2::IPAMResourceDiscovery": "694c0afb626c30d8",
     "AWS::EC2::IPAMResourceDiscoveryAssociation": "fde93486402ddbe5",
@@ -437,7 +438,7 @@ types: dict[str, str] = {
     "AWS::EC2::SecurityGroupIngress": "367136b2f03f428c",
     "AWS::EC2::SecurityGroupVpcAssociation": "f48680388ee894fe",
     "AWS::EC2::SnapshotBlockPublicAccess": "f6434397a8c7e382",
-    "AWS::EC2::SpotFleet": "d389b8af6ecb0e0b",
+    "AWS::EC2::SpotFleet": "b3c6b5b2f4a5b7d2",
     "AWS::EC2::Subnet": "a60b8dc0c7f50396",
     "AWS::EC2::SubnetCidrBlock": "473785ce782ba18f",
     "AWS::EC2::SubnetNetworkAclAssociation": "6b4f4042734e67b7",
@@ -474,7 +475,8 @@ types: dict[str, str] = {
     "AWS::EC2::VPCEndpointServicePermissions": "5841ea22a0cbb143",
     "AWS::EC2::VPCGatewayAttachment": "1dc77043848e8e94",
     "AWS::EC2::VPCPeeringConnection": "e01a466d269170ed",
-    "AWS::EC2::VPNConnection": "0f47659c40e916e6",
+    "AWS::EC2::VPNConcentrator": "78aca3962b6da301",
+    "AWS::EC2::VPNConnection": "96656bab170e1c0b",
     "AWS::EC2::VPNConnectionRoute": "00194e67a2d7f53d",
     "AWS::EC2::VPNGateway": "1e2f029e99547e1a",
     "AWS::EC2::VPNGatewayRoutePropagation": "5e03d41fa9dc15b9",
@@ -492,7 +494,7 @@ types: dict[str, str] = {
     "AWS::ECR::Repository": "d569f41026af3be8",
     "AWS::ECR::RepositoryCreationTemplate": "38e9548ebe8ec1f5",
     "AWS::ECR::SigningConfiguration": "c502bcdb31b67cc1",
-    "AWS::ECS::CapacityProvider": "683155ff5bdccc42",
+    "AWS::ECS::CapacityProvider": "7dac44a9d26fc538",
     "AWS::ECS::Cluster": "3990111074eac8be",
     "AWS::ECS::ClusterCapacityProviderAssociations": "4b512d1fe30ffdd3",
     "AWS::ECS::ExpressGatewayService": "a04769bd1a468834",
@@ -509,7 +511,7 @@ types: dict[str, str] = {
     "AWS::EKS::Cluster": "f17916cc287d09df",
     "AWS::EKS::FargateProfile": "71e821ce6e609193",
     "AWS::EKS::IdentityProviderConfig": "77b807192827540b",
-    "AWS::EKS::Nodegroup": "287f4d78035a9e03",
+    "AWS::EKS::Nodegroup": "4b7b3ba6fffc3e8a",
     "AWS::EKS::PodIdentityAssociation": "d4249aaeb9409683",
     "AWS::EMR::Cluster": "ac0466c8197ef416",
     "AWS::EMR::InstanceFleetConfig": "7c6308bb9ea61ce8",
@@ -521,7 +523,7 @@ types: dict[str, str] = {
     "AWS::EMR::WALWorkspace": "1acf5569fff4fcbe",
     "AWS::EMRContainers::VirtualCluster": "d56c1799bc259539",
     "AWS::EMRServerless::Application": "b8f0bd50831c9f1e",
-    "AWS::EVS::Environment": "8cbba6115db38908",
+    "AWS::EVS::Environment": "de40f0a1095cfeb8",
     "AWS::ElastiCache::CacheCluster": "1220b6bbd633ae68",
     "AWS::ElastiCache::GlobalReplicationGroup": "2af3062bf5b2cf7f",
     "AWS::ElastiCache::ParameterGroup": "b0e1dec3cd05f739",
@@ -575,13 +577,13 @@ types: dict[str, str] = {
     "AWS::FinSpace::Environment": "65bde1d73dcd8a5b",
     "AWS::GameLift::Alias": "5c014b121a693be2",
     "AWS::GameLift::Build": "b9b218f4180db0c3",
-    "AWS::GameLift::Fleet": "7b1de719fe632688",
+    "AWS::GameLift::Fleet": "08322d2081d018bb",
     "AWS::GameLift::GameServerGroup": "5cc95b605dfa9939",
     "AWS::GameLift::GameSessionQueue": "aba577170457cc78",
     "AWS::GameLift::Location": "74151dc88b4069da",
     "AWS::GameLift::MatchmakingConfiguration": "b3a52351df7bf443",
     "AWS::GameLift::MatchmakingRuleSet": "8e5d97e0ee9acaa8",
-    "AWS::GameLift::Script": "d2777b50e200b1a3",
+    "AWS::GameLift::Script": "4571db51b8dc638d",
     "AWS::GlobalAccelerator::Accelerator": "8c74434fcd81b4e7",
     "AWS::GlobalAccelerator::CrossAccountAttachment": "8c37543e6efb0b27",
     "AWS::GlobalAccelerator::EndpointGroup": "f81aee5bef7cb0c1",
@@ -667,7 +669,7 @@ types: dict[str, str] = {
     "AWS::IoT::EncryptionConfiguration": "04291b59f537a48b",
     "AWS::IoT::FleetMetric": "fb5c21ce7d031532",
     "AWS::IoT::JobTemplate": "eae048ed2035c0e7",
-    "AWS::IoT::Logging": "519a05631e6736c9",
+    "AWS::IoT::Logging": "f6aacb672237a289",
     "AWS::IoT::MitigationAction": "35f9780b4ce4f2d1",
     "AWS::IoT::Policy": "0a051e10c89375bb",
     "AWS::IoT::PolicyPrincipalAttachment": "df0e6a915a42650b",
@@ -700,7 +702,7 @@ types: dict[str, str] = {
     "AWS::KMS::Alias": "28f10f922a4d194f",
     "AWS::KMS::Key": "c70e396ee12ddb65",
     "AWS::KMS::ReplicaKey": "903f43e74c8d8853",
-    "AWS::KafkaConnect::Connector": "08b81c973eb812dd",
+    "AWS::KafkaConnect::Connector": "9ca5dec677704b80",
     "AWS::KafkaConnect::CustomPlugin": "f04fc57818e8ddb4",
     "AWS::KafkaConnect::WorkerConfiguration": "8a9b885926e8a00c",
     "AWS::Kendra::DataSource": "46ba2f6e9c75d715",
@@ -770,7 +772,7 @@ types: dict[str, str] = {
     "AWS::Logs::Destination": "ff1e6b020f2cf8e7",
     "AWS::Logs::Integration": "0bc4c86432380358",
     "AWS::Logs::LogAnomalyDetector": "e2ee984f7c775ef5",
-    "AWS::Logs::LogGroup": "7144d581f2e97160",
+    "AWS::Logs::LogGroup": "364a0898ae2cfeb8",
     "AWS::Logs::LogStream": "bb97d1fb38ff99db",
     "AWS::Logs::MetricFilter": "9a1d875b35cd0f81",
     "AWS::Logs::QueryDefinition": "7b82b12db189c1d9",
@@ -788,6 +790,7 @@ types: dict[str, str] = {
     "AWS::MSK::ServerlessCluster": "9eb8b6f85a407e2e",
     "AWS::MSK::VpcConnection": "6aeb07916b90c80a",
     "AWS::MWAA::Environment": "c28ab3624f1d638c",
+    "AWS::MWAAServerless::Workflow": "52e9442d497d660d",
     "AWS::Macie::AllowList": "40bd0a0377639bda",
     "AWS::Macie::CustomDataIdentifier": "c0c5ba901caafe31",
     "AWS::Macie::FindingsFilter": "d3c6be2a3d872987",
@@ -822,7 +825,7 @@ types: dict[str, str] = {
     "AWS::MediaPackageV2::Channel": "62a1a362e9e8f627",
     "AWS::MediaPackageV2::ChannelGroup": "2aa9c5f3fad67e76",
     "AWS::MediaPackageV2::ChannelPolicy": "e79aba75cf23e354",
-    "AWS::MediaPackageV2::OriginEndpoint": "14921a18e39abb19",
+    "AWS::MediaPackageV2::OriginEndpoint": "ebe0f0a5cdb97975",
     "AWS::MediaPackageV2::OriginEndpointPolicy": "8cd12a52dceffffe",
     "AWS::MediaTailor::Channel": "fe2dcc2566975851",
     "AWS::MediaTailor::ChannelPolicy": "1c9cf783f5b18afb",
@@ -870,6 +873,7 @@ types: dict[str, str] = {
     "AWS::Oam::Sink": "81957ea027e4c201",
     "AWS::ObservabilityAdmin::OrganizationCentralizationRule": "6921de30f2cef3a3",
     "AWS::ObservabilityAdmin::OrganizationTelemetryRule": "4f702fc11306cf74",
+    "AWS::ObservabilityAdmin::S3TableIntegration": "9dcd4f79cf41f229",
     "AWS::ObservabilityAdmin::TelemetryPipelines": "1acc5affc6615ad2",
     "AWS::ObservabilityAdmin::TelemetryRule": "a54d5e794c37e6c1",
     "AWS::OpenSearchServerless::AccessPolicy": "ec7a348a493d8c4f",
@@ -934,10 +938,10 @@ types: dict[str, str] = {
     "AWS::Proton::ServiceTemplate": "d29d4f46a846815a",
     "AWS::QLDB::Stream": "09aa8fbe0fae7277",
     "AWS::QuickSight::Analysis": "9ed141915b114fbd",
-    "AWS::QuickSight::CustomPermissions": "ac2895cdbe3ee0f3",
+    "AWS::QuickSight::CustomPermissions": "da6da182c0c23fb4",
     "AWS::QuickSight::Dashboard": "b1b7368590994f86",
     "AWS::QuickSight::DataSet": "0e9e94a2fd9e8f95",
-    "AWS::QuickSight::DataSource": "2c06940063cc0519",
+    "AWS::QuickSight::DataSource": "407708b753626383",
     "AWS::QuickSight::Folder": "4a9e4af92dbcc718",
     "AWS::QuickSight::RefreshSchedule": "0e848e5d85a17427",
     "AWS::QuickSight::Template": "9f99a52291094b16",
@@ -946,14 +950,14 @@ types: dict[str, str] = {
     "AWS::QuickSight::VPCConnection": "96804832324c84da",
     "AWS::RAM::Permission": "740a6e8ada63a5a3",
     "AWS::RAM::ResourceShare": "b4b5ff31bc5f95b0",
-    "AWS::RDS::CustomDBEngineVersion": "e9699c76b9971105",
+    "AWS::RDS::CustomDBEngineVersion": "67b3a7d6ee10021d",
     "AWS::RDS::DBCluster": "9c7540d3d4699497",
     "AWS::RDS::DBClusterParameterGroup": "4e3460620664c07f",
-    "AWS::RDS::DBInstance": "b7cc196bc1fe0b0d",
+    "AWS::RDS::DBInstance": "25726c9e8467f4c5",
     "AWS::RDS::DBParameterGroup": "d29cf38b861f6048",
-    "AWS::RDS::DBProxy": "6a3bd3de0c3a9c96",
-    "AWS::RDS::DBProxyEndpoint": "db0fcba23f51c12d",
-    "AWS::RDS::DBProxyTargetGroup": "8ee69ccb4de53286",
+    "AWS::RDS::DBProxy": "308e70305b33a892",
+    "AWS::RDS::DBProxyEndpoint": "17943cc672d084c2",
+    "AWS::RDS::DBProxyTargetGroup": "b584b6fb42fcd4c7",
     "AWS::RDS::DBSecurityGroup": "42f555e782cd9946",
     "AWS::RDS::DBSecurityGroupIngress": "1a14ad6e73c0b6b7",
     "AWS::RDS::DBShardGroup": "df6b36c7e099595a",
@@ -1038,7 +1042,7 @@ types: dict[str, str] = {
     "AWS::S3Vectors::VectorBucket": "eae6d86b8ee33282",
     "AWS::S3Vectors::VectorBucketPolicy": "ecd7e75e3e0d291d",
     "AWS::SDB::Domain": "48c38397df169b43",
-    "AWS::SES::ConfigurationSet": "77b6745a5f444407",
+    "AWS::SES::ConfigurationSet": "97470ae3c0d408ae",
     "AWS::SES::ConfigurationSetEventDestination": "f4e74b1d7e859c34",
     "AWS::SES::ContactList": "c5a40d0f3d530e19",
     "AWS::SES::DedicatedIpPool": "1485a5989d771f62",
@@ -1120,13 +1124,13 @@ types: dict[str, str] = {
     "AWS::SageMaker::MonitoringSchedule": "aa0115534ffe6a87",
     "AWS::SageMaker::NotebookInstance": "f222a6268560b3b6",
     "AWS::SageMaker::NotebookInstanceLifecycleConfig": "f0d21af114094fa4",
-    "AWS::SageMaker::PartnerApp": "c7fea6d3959a50e9",
+    "AWS::SageMaker::PartnerApp": "f8b0a148c260cb56",
     "AWS::SageMaker::Pipeline": "34dda455906546ac",
     "AWS::SageMaker::ProcessingJob": "9bf6e74e7f3d53e1",
     "AWS::SageMaker::Project": "c10c82bc5a09a5dc",
     "AWS::SageMaker::Space": "a50f6b85f86355b5",
     "AWS::SageMaker::StudioLifecycleConfig": "5b453bb7816eb95b",
-    "AWS::SageMaker::UserProfile": "d2a4b7455b2cbd74",
+    "AWS::SageMaker::UserProfile": "6300c02533605472",
     "AWS::SageMaker::Workteam": "d617e40122a8fe93",
     "AWS::Scheduler::Schedule": "e8b60514af25a837",
     "AWS::Scheduler::ScheduleGroup": "ef710d09dbb243bf",
@@ -1245,21 +1249,21 @@ types: dict[str, str] = {
     "AWS::WAFv2::RuleGroup": "b1d084941142148b",
     "AWS::WAFv2::WebACL": "892990086386d387",
     "AWS::WAFv2::WebACLAssociation": "d0181fa0b0d2faac",
-    "AWS::Wisdom::AIAgent": "a27424c39bbaeffd",
+    "AWS::Wisdom::AIAgent": "5ee8ab1c7c6da31a",
     "AWS::Wisdom::AIAgentVersion": "ebc006eddb995353",
     "AWS::Wisdom::AIGuardrail": "b55d708e74222e39",
     "AWS::Wisdom::AIGuardrailVersion": "18170fb3d4df70e6",
-    "AWS::Wisdom::AIPrompt": "7d88936dace0860f",
+    "AWS::Wisdom::AIPrompt": "839755a4af72ed27",
     "AWS::Wisdom::AIPromptVersion": "f1eb16962e464a28",
     "AWS::Wisdom::Assistant": "b334f5c54b6c51a1",
-    "AWS::Wisdom::AssistantAssociation": "8208fce50ec6026e",
+    "AWS::Wisdom::AssistantAssociation": "5f451a4494207cd5",
     "AWS::Wisdom::KnowledgeBase": "7a9b74f6c142ebfc",
     "AWS::Wisdom::MessageTemplate": "abd2a7d623bd398f",
     "AWS::Wisdom::MessageTemplateVersion": "85d93c94b16a675a",
     "AWS::Wisdom::QuickResponse": "f1a6189fe08948ad",
     "AWS::WorkSpaces::ConnectionAlias": "da70493ea10990d6",
     "AWS::WorkSpaces::Workspace": "97435699d74bcbe8",
-    "AWS::WorkSpaces::WorkspacesPool": "f4472bf2fa403578",
+    "AWS::WorkSpaces::WorkspacesPool": "321a927105979c95",
     "AWS::WorkSpacesThinClient::Environment": "7bbf7b66606e0a09",
     "AWS::WorkSpacesWeb::BrowserSettings": "c64ccfb879da5c48",
     "AWS::WorkSpacesWeb::DataProtectionSettings": "07a9150a1ae32491",
@@ -1271,7 +1275,7 @@ types: dict[str, str] = {
     "AWS::WorkSpacesWeb::TrustStore": "0da7818c34767162",
     "AWS::WorkSpacesWeb::UserAccessLoggingSettings": "13399f9f750bfb0f",
     "AWS::WorkSpacesWeb::UserSettings": "ba71e0f7174cdbe2",
-    "AWS::WorkspacesInstances::Volume": "783536e2ad8748b1",
+    "AWS::WorkspacesInstances::Volume": "dc5bec0e6e8edd13",
     "AWS::WorkspacesInstances::VolumeAssociation": "de659b329d22edbd",
     "AWS::WorkspacesInstances::WorkspaceInstance": "d9e9f739e378d7cd",
     "AWS::XRay::Group": "81cf1b3bfd81fc73",
