@@ -132,7 +132,7 @@ types: dict[str, str] = {
     "AWS::B2BI::Partnership": "cf1dd17e2f4a01e1",
     "AWS::B2BI::Profile": "bffe6301271de8b8",
     "AWS::B2BI::Transformer": "a589436ad3f8e8e5",
-    "AWS::Backup::BackupPlan": "72bcc201f012e665",
+    "AWS::Backup::BackupPlan": "320b6510a85d684e",
     "AWS::Backup::BackupSelection": "26040166156c899a",
     "AWS::Backup::BackupVault": "695e80a4aaec9275",
     "AWS::Backup::Framework": "df47da6f2d6712da",
@@ -164,8 +164,8 @@ types: dict[str, str] = {
     "AWS::Bedrock::PromptVersion": "41e3e79078ba156a",
     "AWS::BedrockAgentCore::BrowserCustom": "b3f585b2b83595e9",
     "AWS::BedrockAgentCore::CodeInterpreterCustom": "a4789ce5aa400e99",
-    "AWS::BedrockAgentCore::Gateway": "247c1db4e4082ec0",
-    "AWS::BedrockAgentCore::GatewayTarget": "2214118622bce5a2",
+    "AWS::BedrockAgentCore::Gateway": "a629441d622699ce",
+    "AWS::BedrockAgentCore::GatewayTarget": "f190da008ea2a70a",
     "AWS::BedrockAgentCore::Memory": "87837077e3884e10",
     "AWS::BedrockAgentCore::Runtime": "691d685a9f3413ad",
     "AWS::BedrockAgentCore::RuntimeEndpoint": "624b26411473f25c",
@@ -184,8 +184,8 @@ types: dict[str, str] = {
     "AWS::Chatbot::CustomAction": "f8ad09ff43d3bb61",
     "AWS::Chatbot::MicrosoftTeamsChannelConfiguration": "010fe053ff4053d8",
     "AWS::Chatbot::SlackChannelConfiguration": "733a3e7b4bdf0053",
-    "AWS::CleanRooms::AnalysisTemplate": "fa83ca65f4bbb876",
-    "AWS::CleanRooms::Collaboration": "fa1593af917ba247",
+    "AWS::CleanRooms::AnalysisTemplate": "67d664e683d48497",
+    "AWS::CleanRooms::Collaboration": "41841e7383f88f94",
     "AWS::CleanRooms::ConfiguredTable": "2e7f2a7ba2926d27",
     "AWS::CleanRooms::ConfiguredTableAssociation": "2d7fbce0930cc73d",
     "AWS::CleanRooms::IdMappingTable": "2a5b2698a99d13ae",
@@ -332,13 +332,13 @@ types: dict[str, str] = {
     "AWS::DataSync::LocationS3": "0190e1a20831d5e0",
     "AWS::DataSync::LocationSMB": "84f56a8c81ace8fd",
     "AWS::DataSync::Task": "d896b335ffc11f10",
-    "AWS::DataZone::Connection": "4c5bd872b555a360",
-    "AWS::DataZone::DataSource": "45679439037c4108",
+    "AWS::DataZone::Connection": "36206200921236e5",
+    "AWS::DataZone::DataSource": "5522a6a5cd1e1a3e",
     "AWS::DataZone::Domain": "a73fade42476d81b",
     "AWS::DataZone::DomainUnit": "711f0c6aabf717bd",
     "AWS::DataZone::Environment": "90d9cbf3a3ed746b",
     "AWS::DataZone::EnvironmentActions": "74f98b0cb8b35451",
-    "AWS::DataZone::EnvironmentBlueprintConfiguration": "3aeda3b79f4458c1",
+    "AWS::DataZone::EnvironmentBlueprintConfiguration": "2eaef7d5eed54c20",
     "AWS::DataZone::EnvironmentProfile": "e0cb32e5d86cbc08",
     "AWS::DataZone::FormType": "c4cdf1e5e0a284ed",
     "AWS::DataZone::GroupProfile": "74ae2ae09d16d68e",
@@ -346,8 +346,8 @@ types: dict[str, str] = {
     "AWS::DataZone::PolicyGrant": "4a122be9c506c908",
     "AWS::DataZone::Project": "2f7d1fc808f3eed8",
     "AWS::DataZone::ProjectMembership": "9afaeb6b2c0a7ad8",
-    "AWS::DataZone::ProjectProfile": "fb23ccf55c4c1ec7",
-    "AWS::DataZone::SubscriptionTarget": "b9b0c7c5b0d7c587",
+    "AWS::DataZone::ProjectProfile": "069e12fef6b972f5",
+    "AWS::DataZone::SubscriptionTarget": "ed731ffbd196f802",
     "AWS::DataZone::UserProfile": "db3a5863b7d055bd",
     "AWS::Deadline::Farm": "c9bbcca2240de1e6",
     "AWS::Deadline::Fleet": "b90dfd2bd6566e09",
@@ -373,8 +373,9 @@ types: dict[str, str] = {
     "AWS::DocDB::DBInstance": "253562f270b587ac",
     "AWS::DocDB::DBSubnetGroup": "ccb97a9452b2284d",
     "AWS::DocDB::EventSubscription": "d22815028d03f301",
+    "AWS::DocDB::GlobalCluster": "8a43a2ee7a595e9a",
     "AWS::DocDBElastic::Cluster": "5686e00f54e9aae6",
-    "AWS::DynamoDB::GlobalTable": "1789ed6c17b2b960",
+    "AWS::DynamoDB::GlobalTable": "bfb73ef91cc656d2",
     "AWS::DynamoDB::Table": "8e1902cddc19c9ad",
     "AWS::EC2::CapacityManagerDataExport": "eadbbd5d7fd8fd3c",
     "AWS::EC2::CapacityReservation": "d8685a879c65fa62",
@@ -386,7 +387,7 @@ types: dict[str, str] = {
     "AWS::EC2::ClientVpnTargetNetworkAssociation": "d69233d655faf0f6",
     "AWS::EC2::CustomerGateway": "4003177e29b1dfc5",
     "AWS::EC2::DHCPOptions": "7794e3a54eaacb7a",
-    "AWS::EC2::EC2Fleet": "2667c807051620b3",
+    "AWS::EC2::EC2Fleet": "46456be2fbbfb010",
     "AWS::EC2::EIP": "cc42df82cdc81e9c",
     "AWS::EC2::EIPAssociation": "a267820d6250f189",
     "AWS::EC2::EgressOnlyInternetGateway": "922c59e19b698eac",
@@ -396,7 +397,7 @@ types: dict[str, str] = {
     "AWS::EC2::Host": "ba21ffd03e701456",
     "AWS::EC2::IPAM": "6fc9a0643e75121d",
     "AWS::EC2::IPAMAllocation": "c4cba824ca02ce4f",
-    "AWS::EC2::IPAMPool": "99dd938378f53c74",
+    "AWS::EC2::IPAMPool": "0509442cdc1e18b1",
     "AWS::EC2::IPAMPoolCidr": "873e7cc6e6afef96",
     "AWS::EC2::IPAMResourceDiscovery": "694c0afb626c30d8",
     "AWS::EC2::IPAMResourceDiscoveryAssociation": "fde93486402ddbe5",
@@ -438,7 +439,7 @@ types: dict[str, str] = {
     "AWS::EC2::SecurityGroupIngress": "367136b2f03f428c",
     "AWS::EC2::SecurityGroupVpcAssociation": "f48680388ee894fe",
     "AWS::EC2::SnapshotBlockPublicAccess": "f6434397a8c7e382",
-    "AWS::EC2::SpotFleet": "d389b8af6ecb0e0b",
+    "AWS::EC2::SpotFleet": "b3c6b5b2f4a5b7d2",
     "AWS::EC2::Subnet": "a60b8dc0c7f50396",
     "AWS::EC2::SubnetCidrBlock": "473785ce782ba18f",
     "AWS::EC2::SubnetNetworkAclAssociation": "6b4f4042734e67b7",
@@ -476,7 +477,7 @@ types: dict[str, str] = {
     "AWS::EC2::VPCGatewayAttachment": "1dc77043848e8e94",
     "AWS::EC2::VPCPeeringConnection": "e01a466d269170ed",
     "AWS::EC2::VPNConcentrator": "78aca3962b6da301",
-    "AWS::EC2::VPNConnection": "0f47659c40e916e6",
+    "AWS::EC2::VPNConnection": "96656bab170e1c0b",
     "AWS::EC2::VPNConnectionRoute": "00194e67a2d7f53d",
     "AWS::EC2::VPNGateway": "1e2f029e99547e1a",
     "AWS::EC2::VPNGatewayRoutePropagation": "5e03d41fa9dc15b9",
@@ -494,7 +495,7 @@ types: dict[str, str] = {
     "AWS::ECR::Repository": "d569f41026af3be8",
     "AWS::ECR::RepositoryCreationTemplate": "38e9548ebe8ec1f5",
     "AWS::ECR::SigningConfiguration": "c502bcdb31b67cc1",
-    "AWS::ECS::CapacityProvider": "683155ff5bdccc42",
+    "AWS::ECS::CapacityProvider": "7dac44a9d26fc538",
     "AWS::ECS::Cluster": "3990111074eac8be",
     "AWS::ECS::ClusterCapacityProviderAssociations": "4b512d1fe30ffdd3",
     "AWS::ECS::ExpressGatewayService": "a04769bd1a468834",
@@ -511,7 +512,7 @@ types: dict[str, str] = {
     "AWS::EKS::Cluster": "f17916cc287d09df",
     "AWS::EKS::FargateProfile": "71e821ce6e609193",
     "AWS::EKS::IdentityProviderConfig": "77b807192827540b",
-    "AWS::EKS::Nodegroup": "287f4d78035a9e03",
+    "AWS::EKS::Nodegroup": "4b7b3ba6fffc3e8a",
     "AWS::EKS::PodIdentityAssociation": "d4249aaeb9409683",
     "AWS::EMR::Cluster": "ac0466c8197ef416",
     "AWS::EMR::InstanceFleetConfig": "7c6308bb9ea61ce8",
@@ -523,7 +524,7 @@ types: dict[str, str] = {
     "AWS::EMR::WALWorkspace": "1acf5569fff4fcbe",
     "AWS::EMRContainers::VirtualCluster": "d56c1799bc259539",
     "AWS::EMRServerless::Application": "b8f0bd50831c9f1e",
-    "AWS::EVS::Environment": "8cbba6115db38908",
+    "AWS::EVS::Environment": "de40f0a1095cfeb8",
     "AWS::ElastiCache::CacheCluster": "1220b6bbd633ae68",
     "AWS::ElastiCache::GlobalReplicationGroup": "2af3062bf5b2cf7f",
     "AWS::ElastiCache::ParameterGroup": "b0e1dec3cd05f739",
@@ -591,13 +592,13 @@ types: dict[str, str] = {
     "AWS::FraudDetector::Variable": "2e6f2ffc6a3c7b4c",
     "AWS::GameLift::Alias": "5c014b121a693be2",
     "AWS::GameLift::Build": "b9b218f4180db0c3",
-    "AWS::GameLift::Fleet": "7b1de719fe632688",
+    "AWS::GameLift::Fleet": "08322d2081d018bb",
     "AWS::GameLift::GameServerGroup": "5cc95b605dfa9939",
     "AWS::GameLift::GameSessionQueue": "aba577170457cc78",
     "AWS::GameLift::Location": "74151dc88b4069da",
     "AWS::GameLift::MatchmakingConfiguration": "b3a52351df7bf443",
     "AWS::GameLift::MatchmakingRuleSet": "8e5d97e0ee9acaa8",
-    "AWS::GameLift::Script": "d2777b50e200b1a3",
+    "AWS::GameLift::Script": "4571db51b8dc638d",
     "AWS::GameLiftStreams::Application": "e5247f2714d07520",
     "AWS::GameLiftStreams::StreamGroup": "9cfe900193607520",
     "AWS::GlobalAccelerator::Accelerator": "8c74434fcd81b4e7",
@@ -745,7 +746,7 @@ types: dict[str, str] = {
     "AWS::KMS::Alias": "28f10f922a4d194f",
     "AWS::KMS::Key": "c70e396ee12ddb65",
     "AWS::KMS::ReplicaKey": "903f43e74c8d8853",
-    "AWS::KafkaConnect::Connector": "08b81c973eb812dd",
+    "AWS::KafkaConnect::Connector": "9ca5dec677704b80",
     "AWS::KafkaConnect::CustomPlugin": "f04fc57818e8ddb4",
     "AWS::KafkaConnect::WorkerConfiguration": "8a9b885926e8a00c",
     "AWS::Kendra::DataSource": "46ba2f6e9c75d715",
@@ -812,7 +813,7 @@ types: dict[str, str] = {
     "AWS::Logs::Destination": "ff1e6b020f2cf8e7",
     "AWS::Logs::Integration": "0bc4c86432380358",
     "AWS::Logs::LogAnomalyDetector": "e2ee984f7c775ef5",
-    "AWS::Logs::LogGroup": "7144d581f2e97160",
+    "AWS::Logs::LogGroup": "364a0898ae2cfeb8",
     "AWS::Logs::LogStream": "bb97d1fb38ff99db",
     "AWS::Logs::MetricFilter": "9a1d875b35cd0f81",
     "AWS::Logs::QueryDefinition": "7b82b12db189c1d9",
@@ -831,6 +832,7 @@ types: dict[str, str] = {
     "AWS::MSK::ServerlessCluster": "9eb8b6f85a407e2e",
     "AWS::MSK::VpcConnection": "6aeb07916b90c80a",
     "AWS::MWAA::Environment": "c28ab3624f1d638c",
+    "AWS::MWAAServerless::Workflow": "52e9442d497d660d",
     "AWS::Macie::AllowList": "40bd0a0377639bda",
     "AWS::Macie::CustomDataIdentifier": "c0c5ba901caafe31",
     "AWS::Macie::FindingsFilter": "d3c6be2a3d872987",
@@ -872,7 +874,7 @@ types: dict[str, str] = {
     "AWS::MediaPackageV2::Channel": "62a1a362e9e8f627",
     "AWS::MediaPackageV2::ChannelGroup": "2aa9c5f3fad67e76",
     "AWS::MediaPackageV2::ChannelPolicy": "e79aba75cf23e354",
-    "AWS::MediaPackageV2::OriginEndpoint": "14921a18e39abb19",
+    "AWS::MediaPackageV2::OriginEndpoint": "ebe0f0a5cdb97975",
     "AWS::MediaPackageV2::OriginEndpointPolicy": "8cd12a52dceffffe",
     "AWS::MediaTailor::Channel": "fe2dcc2566975851",
     "AWS::MediaTailor::ChannelPolicy": "1c9cf783f5b18afb",
@@ -975,10 +977,10 @@ types: dict[str, str] = {
     "AWS::QLDB::Ledger": "eb38fe7089c60665",
     "AWS::QLDB::Stream": "09aa8fbe0fae7277",
     "AWS::QuickSight::Analysis": "9ed141915b114fbd",
-    "AWS::QuickSight::CustomPermissions": "ac2895cdbe3ee0f3",
+    "AWS::QuickSight::CustomPermissions": "da6da182c0c23fb4",
     "AWS::QuickSight::Dashboard": "b1b7368590994f86",
     "AWS::QuickSight::DataSet": "0e9e94a2fd9e8f95",
-    "AWS::QuickSight::DataSource": "2c06940063cc0519",
+    "AWS::QuickSight::DataSource": "407708b753626383",
     "AWS::QuickSight::Folder": "4a9e4af92dbcc718",
     "AWS::QuickSight::RefreshSchedule": "0e848e5d85a17427",
     "AWS::QuickSight::Template": "9f99a52291094b16",
@@ -987,14 +989,14 @@ types: dict[str, str] = {
     "AWS::QuickSight::VPCConnection": "96804832324c84da",
     "AWS::RAM::Permission": "740a6e8ada63a5a3",
     "AWS::RAM::ResourceShare": "b4b5ff31bc5f95b0",
-    "AWS::RDS::CustomDBEngineVersion": "e9699c76b9971105",
+    "AWS::RDS::CustomDBEngineVersion": "67b3a7d6ee10021d",
     "AWS::RDS::DBCluster": "9c7540d3d4699497",
     "AWS::RDS::DBClusterParameterGroup": "4e3460620664c07f",
-    "AWS::RDS::DBInstance": "b7cc196bc1fe0b0d",
+    "AWS::RDS::DBInstance": "25726c9e8467f4c5",
     "AWS::RDS::DBParameterGroup": "d29cf38b861f6048",
-    "AWS::RDS::DBProxy": "6a3bd3de0c3a9c96",
-    "AWS::RDS::DBProxyEndpoint": "db0fcba23f51c12d",
-    "AWS::RDS::DBProxyTargetGroup": "8ee69ccb4de53286",
+    "AWS::RDS::DBProxy": "308e70305b33a892",
+    "AWS::RDS::DBProxyEndpoint": "17943cc672d084c2",
+    "AWS::RDS::DBProxyTargetGroup": "b584b6fb42fcd4c7",
     "AWS::RDS::DBSecurityGroup": "42f555e782cd9946",
     "AWS::RDS::DBSecurityGroupIngress": "1a14ad6e73c0b6b7",
     "AWS::RDS::DBShardGroup": "df6b36c7e099595a",
@@ -1084,7 +1086,7 @@ types: dict[str, str] = {
     "AWS::S3Vectors::VectorBucket": "eae6d86b8ee33282",
     "AWS::S3Vectors::VectorBucketPolicy": "ecd7e75e3e0d291d",
     "AWS::SDB::Domain": "48c38397df169b43",
-    "AWS::SES::ConfigurationSet": "77b6745a5f444407",
+    "AWS::SES::ConfigurationSet": "97470ae3c0d408ae",
     "AWS::SES::ConfigurationSetEventDestination": "f4e74b1d7e859c34",
     "AWS::SES::ContactList": "c5a40d0f3d530e19",
     "AWS::SES::DedicatedIpPool": "1485a5989d771f62",
@@ -1168,13 +1170,13 @@ types: dict[str, str] = {
     "AWS::SageMaker::MonitoringSchedule": "aa0115534ffe6a87",
     "AWS::SageMaker::NotebookInstance": "f222a6268560b3b6",
     "AWS::SageMaker::NotebookInstanceLifecycleConfig": "f0d21af114094fa4",
-    "AWS::SageMaker::PartnerApp": "c7fea6d3959a50e9",
+    "AWS::SageMaker::PartnerApp": "f8b0a148c260cb56",
     "AWS::SageMaker::Pipeline": "34dda455906546ac",
     "AWS::SageMaker::ProcessingJob": "9bf6e74e7f3d53e1",
     "AWS::SageMaker::Project": "c10c82bc5a09a5dc",
     "AWS::SageMaker::Space": "a50f6b85f86355b5",
     "AWS::SageMaker::StudioLifecycleConfig": "5b453bb7816eb95b",
-    "AWS::SageMaker::UserProfile": "d2a4b7455b2cbd74",
+    "AWS::SageMaker::UserProfile": "6300c02533605472",
     "AWS::SageMaker::Workteam": "d617e40122a8fe93",
     "AWS::Scheduler::Schedule": "e8b60514af25a837",
     "AWS::Scheduler::ScheduleGroup": "ef710d09dbb243bf",
