@@ -91,7 +91,7 @@ types: dict[str, str] = {
     "AWS::AutoScaling::ScalingPolicy": "3a71f2160c19e614",
     "AWS::AutoScaling::ScheduledAction": "ab00e084f1d921e6",
     "AWS::AutoScaling::WarmPool": "93498a4faffea6ae",
-    "AWS::Backup::BackupPlan": "72bcc201f012e665",
+    "AWS::Backup::BackupPlan": "320b6510a85d684e",
     "AWS::Backup::BackupSelection": "26040166156c899a",
     "AWS::Backup::BackupVault": "695e80a4aaec9275",
     "AWS::Backup::Framework": "df47da6f2d6712da",
@@ -152,7 +152,7 @@ types: dict[str, str] = {
     "AWS::CodeDeploy::DeploymentConfig": "394f39ae21382747",
     "AWS::CodeDeploy::DeploymentGroup": "36c8d71f30ed60e4",
     "AWS::CodePipeline::CustomActionType": "726ad61840645aa5",
-    "AWS::CodePipeline::Pipeline": "4a5fa25f94471a0a",
+    "AWS::CodePipeline::Pipeline": "580b88b2161ff941",
     "AWS::CodePipeline::Webhook": "a6ad2a4dc85ed032",
     "AWS::CodeStarConnections::Connection": "6b8c8b99af488ddd",
     "AWS::Cognito::IdentityPool": "3df22057c8e2ef54",
@@ -214,7 +214,8 @@ types: dict[str, str] = {
     "AWS::DocDB::DBInstance": "253562f270b587ac",
     "AWS::DocDB::DBSubnetGroup": "ccb97a9452b2284d",
     "AWS::DocDB::EventSubscription": "d22815028d03f301",
-    "AWS::DynamoDB::GlobalTable": "1789ed6c17b2b960",
+    "AWS::DocDB::GlobalCluster": "8a43a2ee7a595e9a",
+    "AWS::DynamoDB::GlobalTable": "bfb73ef91cc656d2",
     "AWS::DynamoDB::Table": "8e1902cddc19c9ad",
     "AWS::EC2::CapacityReservation": "d8685a879c65fa62",
     "AWS::EC2::CapacityReservationFleet": "3cec76abc326e6e7",
@@ -303,7 +304,7 @@ types: dict[str, str] = {
     "AWS::EC2::VPCGatewayAttachment": "1dc77043848e8e94",
     "AWS::EC2::VPCPeeringConnection": "e01a466d269170ed",
     "AWS::EC2::VPNConcentrator": "78aca3962b6da301",
-    "AWS::EC2::VPNConnection": "0f47659c40e916e6",
+    "AWS::EC2::VPNConnection": "96656bab170e1c0b",
     "AWS::EC2::VPNConnectionRoute": "00194e67a2d7f53d",
     "AWS::EC2::VPNGateway": "1e2f029e99547e1a",
     "AWS::EC2::VPNGatewayRoutePropagation": "5e03d41fa9dc15b9",
@@ -320,7 +321,7 @@ types: dict[str, str] = {
     "AWS::ECR::Repository": "d569f41026af3be8",
     "AWS::ECR::RepositoryCreationTemplate": "38e9548ebe8ec1f5",
     "AWS::ECR::SigningConfiguration": "c502bcdb31b67cc1",
-    "AWS::ECS::CapacityProvider": "683155ff5bdccc42",
+    "AWS::ECS::CapacityProvider": "7dac44a9d26fc538",
     "AWS::ECS::Cluster": "3990111074eac8be",
     "AWS::ECS::ClusterCapacityProviderAssociations": "4b512d1fe30ffdd3",
     "AWS::ECS::PrimaryTaskSet": "d8ea9e906cb85b80",
@@ -334,7 +335,7 @@ types: dict[str, str] = {
     "AWS::EKS::Addon": "f27379fa02ce1e45",
     "AWS::EKS::Cluster": "f17916cc287d09df",
     "AWS::EKS::IdentityProviderConfig": "77b807192827540b",
-    "AWS::EKS::Nodegroup": "287f4d78035a9e03",
+    "AWS::EKS::Nodegroup": "4b7b3ba6fffc3e8a",
     "AWS::EKS::PodIdentityAssociation": "d4249aaeb9409683",
     "AWS::EMR::Cluster": "ac0466c8197ef416",
     "AWS::EMR::InstanceFleetConfig": "7c6308bb9ea61ce8",
@@ -378,7 +379,7 @@ types: dict[str, str] = {
     "AWS::Events::Rule": "c57a1bd96161aafc",
     "AWS::FIS::ExperimentTemplate": "0277c14e1157435b",
     "AWS::FIS::TargetAccountConfiguration": "c2959eedf6398b2a",
-    "AWS::FMS::NotificationChannel": "622ce9589b28d75d",
+    "AWS::FMS::NotificationChannel": "3dfde465b38d83be",
     "AWS::FMS::Policy": "3d3868b1e974d27b",
     "AWS::FMS::ResourceSet": "6fb04db2dcf50bf8",
     "AWS::FSx::DataRepositoryAssociation": "2c944a4b33c2d639",
@@ -456,7 +457,7 @@ types: dict[str, str] = {
     "AWS::ImageBuilder::Component": "c686558ba853a496",
     "AWS::ImageBuilder::ContainerRecipe": "882a5a874ec51f81",
     "AWS::ImageBuilder::DistributionConfiguration": "7b34e1b0b9958d96",
-    "AWS::ImageBuilder::Image": "c690c6fdfc55f601",
+    "AWS::ImageBuilder::Image": "7eaad9cf0d30061e",
     "AWS::ImageBuilder::ImagePipeline": "8ea2eca13ceb1fc8",
     "AWS::ImageBuilder::ImageRecipe": "83c0121011689366",
     "AWS::ImageBuilder::InfrastructureConfiguration": "703bdd9fb961cbcd",
@@ -538,7 +539,7 @@ types: dict[str, str] = {
     "AWS::Logs::DeliveryDestination": "30b61a3515971eda",
     "AWS::Logs::DeliverySource": "67b64320b397d6cd",
     "AWS::Logs::Destination": "ff1e6b020f2cf8e7",
-    "AWS::Logs::LogGroup": "7144d581f2e97160",
+    "AWS::Logs::LogGroup": "364a0898ae2cfeb8",
     "AWS::Logs::LogStream": "bb97d1fb38ff99db",
     "AWS::Logs::MetricFilter": "9a1d875b35cd0f81",
     "AWS::Logs::QueryDefinition": "7b82b12db189c1d9",
@@ -608,10 +609,10 @@ types: dict[str, str] = {
     "AWS::PCS::ComputeNodeGroup": "18c1af5cf4154c64",
     "AWS::PCS::Queue": "beffbb3966cc89c2",
     "AWS::QuickSight::Analysis": "9ed141915b114fbd",
-    "AWS::QuickSight::CustomPermissions": "ac2895cdbe3ee0f3",
+    "AWS::QuickSight::CustomPermissions": "da6da182c0c23fb4",
     "AWS::QuickSight::Dashboard": "b1b7368590994f86",
     "AWS::QuickSight::DataSet": "0e9e94a2fd9e8f95",
-    "AWS::QuickSight::DataSource": "2c06940063cc0519",
+    "AWS::QuickSight::DataSource": "407708b753626383",
     "AWS::QuickSight::Folder": "4a9e4af92dbcc718",
     "AWS::QuickSight::RefreshSchedule": "0e848e5d85a17427",
     "AWS::QuickSight::Template": "9f99a52291094b16",
@@ -621,11 +622,11 @@ types: dict[str, str] = {
     "AWS::RAM::ResourceShare": "b4b5ff31bc5f95b0",
     "AWS::RDS::DBCluster": "9c7540d3d4699497",
     "AWS::RDS::DBClusterParameterGroup": "4e3460620664c07f",
-    "AWS::RDS::DBInstance": "b7cc196bc1fe0b0d",
+    "AWS::RDS::DBInstance": "25726c9e8467f4c5",
     "AWS::RDS::DBParameterGroup": "d29cf38b861f6048",
-    "AWS::RDS::DBProxy": "6a3bd3de0c3a9c96",
-    "AWS::RDS::DBProxyEndpoint": "db0fcba23f51c12d",
-    "AWS::RDS::DBProxyTargetGroup": "8ee69ccb4de53286",
+    "AWS::RDS::DBProxy": "308e70305b33a892",
+    "AWS::RDS::DBProxyEndpoint": "17943cc672d084c2",
+    "AWS::RDS::DBProxyTargetGroup": "b584b6fb42fcd4c7",
     "AWS::RDS::DBSecurityGroup": "42f555e782cd9946",
     "AWS::RDS::DBSecurityGroupIngress": "1a14ad6e73c0b6b7",
     "AWS::RDS::DBShardGroup": "df6b36c7e099595a",
@@ -678,6 +679,7 @@ types: dict[str, str] = {
     "AWS::S3::AccessPoint": "e8b95810dd8d6917",
     "AWS::S3::Bucket": "bc2a891a463ee5ee",
     "AWS::S3::BucketPolicy": "38ad5b8bd8062535",
+    "AWS::S3::StorageLens": "bb038f16e3dd3fd9",
     "AWS::S3::StorageLensGroup": "a48c03e67d334c14",
     "AWS::S3ObjectLambda::AccessPoint": "2d6b2b82a9508114",
     "AWS::S3ObjectLambda::AccessPointPolicy": "fd6328c6c782223a",
@@ -686,7 +688,7 @@ types: dict[str, str] = {
     "AWS::S3Outposts::BucketPolicy": "29126ab2fb9793f6",
     "AWS::S3Outposts::Endpoint": "323c92664ebd7f95",
     "AWS::SDB::Domain": "48c38397df169b43",
-    "AWS::SES::ConfigurationSet": "77b6745a5f444407",
+    "AWS::SES::ConfigurationSet": "97470ae3c0d408ae",
     "AWS::SES::ConfigurationSetEventDestination": "f4e74b1d7e859c34",
     "AWS::SES::ContactList": "c5a40d0f3d530e19",
     "AWS::SES::DedicatedIpPool": "1485a5989d771f62",
@@ -813,7 +815,7 @@ types: dict[str, str] = {
     "AWS::WAFv2::WebACL": "892990086386d387",
     "AWS::WAFv2::WebACLAssociation": "d0181fa0b0d2faac",
     "AWS::WorkSpaces::Workspace": "97435699d74bcbe8",
-    "AWS::WorkSpaces::WorkspacesPool": "f4472bf2fa403578",
+    "AWS::WorkSpaces::WorkspacesPool": "321a927105979c95",
     "AWS::XRay::Group": "81cf1b3bfd81fc73",
     "AWS::XRay::ResourcePolicy": "1eefd10339461fe6",
     "AWS::XRay::SamplingRule": "0aa60791e2ac7d03",
